import { __decorate } from "tslib";
import { css, html, observable, ref } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
/**
 * The AG Select Editor element.
 * @public
 * @tagname %%prefix%%-select-editor
 */
export class SelectEditor extends FoundationElement {
    init(params) {
        if (!params)
            return;
        this.params = params;
        this.value = params.value;
    }
    getGui() {
        return this;
    }
    destroy() { }
    refresh(params) {
        return true;
    }
    getValue() {
        return this.value;
    }
    isPopup() {
        return true;
    }
    afterGuiAttached() {
        this.combobox.open = true;
    }
}
__decorate([
    observable
], SelectEditor.prototype, "params", void 0);
__decorate([
    observable
], SelectEditor.prototype, "value", void 0);
/**
 * The AG Select Renderer Styles.
 * @public
 */
export const agSelectEditorStyles = css `
  :host,
  .select-renderer,
  zero-option,
  ::part(listbox),
  ::part(control) {
    max-width: var(--select-renderer-max-width);
    min-width: 100%;
  }
`;
/**
 * Get a Design System prefixed Select template.
 * @param designSystem - The design system prefix to use. Defaults to 'foundation'.
 * @returns A Select component template prefixed with the correct design system.
 * @public
 */
export const getSelectEditorTemplate = (designSystem = 'foundation') => html `
  <${designSystem}-combobox
    style="width: 100%"
    ${ref('combobox')}
    @value-change=${(x, c) => {
    var _a;
    x.value = (_a = c.event.detail) === null || _a === void 0 ? void 0 : _a.value;
}}
  >
    <options-datasource
      resourceName=${(x) => x.params.allOptionsResourceName}
      value-field=${(x) => x.params.valueField}
      label-field=${(x) => x.params.labelField}
      :datasourceConfig=${(x) => x.params.datasourceOptions}
      :data=${(x) => x.params.values}
      :initialSelectedValue=${(x) => x.params.value}
    ></options-datasource>
  </${designSystem}-combobox>
`;
/**
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-select-editor\>
 */
export const foundationSelectEditor = SelectEditor.compose({
    baseName: 'select-editor',
    styles: agSelectEditorStyles,
    template: getSelectEditorTemplate(),
});
